<cfif isDefined("form.submit")>
    <cfscript>
        artists = createObject("component", "Artists");
        artists.insertArtist(form);
    </cfscript>

    <font color="#FF0000">
        <cfoutput>
        #form.firstName# #form.lastName# has been inserted into the database.
        </cfoutput>
    </font>
</cfif>

<cfform format="XML" skin="blue" width="200" height="200">
    <cfformgroup type="vertical">
        <cfformitem type="HTML">
            <strong>Add an Artist to the Database</strong>
        </cfformitem>
        <cfinput id="firstName" title="First Name" name="firstName" size="20" maxlength="20" type="text" label="First Name" required="yes" message="First name is required." />
        <cfinput id="lastName" title="Last Name" name="lastName" size="20" maxlength="20" type="text" label="Last Name" required="yes" message="Last name is required." />
        <cfinput id="phone" title="Phone" name="phone" size="15" maxlength="15" type="text" label="Phone" required="yes" message="Please enter a phone number." />
        <cfinput id="submit" title="Insert" name="submit" value="Insert" type="submit" style="margin-left:135px" />
    </cfformgroup>
</cfform>
 
<!---
--------------------------------------------------------------------------------
 
This is a self-referencing form page. That means that both the form and the action are contained on the same page. A conditional cfif statement is placed around the action section at the top of the page to ensure that this code is not run unless the form is submitted. The cfif statement checks for the form.insert submit button variable, which will only exist if the user has submitted the form.

The cfform tags, towards the bottom of the code, wrap the XML form that prompts the user to enter a first name, last name and date of birth. Notice that the submit button is named insert.

The cfinvoke tag in the action section of the page calls the insertArtist method of the Artists.cfc. This CFC will return a boolean value, which the cfinvoke tag has named isSuccessful. 

Note that if isSuccessful is true, then an insert message is outputted to the page. 
--->

<!--- Sample code for the "read uncommitted" attribute
<cftransaction action="begin" isolation="read_uncommitted">
    <cfquery name="getArtists" datasource="#request.dsn#">
        select *
        from GSTARTED.ARTISTS
    </cfquery>
</cftransaction>

<cfdump var="#getArtists#" top="10">
--->


<!--- Add the following code to a file called artists.cfm 
<cfcomponent>
    <cffunction access="public" name="getArtists" output="false" returntype="query">
        <cfset var artistsQuery="">
        <cfquery name="artistsQuery" datasource="#request.dsn#">
            SELECT ARTISTID, FIRSTNAME, LASTNAME, PHONE
            FROM GSTARTED.ARTISTS
            ORDER BY LASTNAME
        </cfquery>
        <cfreturn artistsQuery />
    </cffunction>


    <cffunction access="public" name="insertArtist" output="false" returntype="boolean">
        <cfargument name="formVariables" type="struct" required="yes">
        <cfset isSuccessful=true>
        <cftry>

            <cftransaction action="begin">
                <cfquery name="artistsInsert" datasource="#request.dsn#">
                    INSERT INTO ARTISTS (FIRSTNAME, LASTNAME, PHONE)
                    VALUES (
                        <cfqueryparam cfsqltype="CF_SQL_VARCHAR" value="#arguments.formVariables.firstName#">
                        , <cfqueryparam cfsqltype="CF_SQL_VARCHAR" value="#arguments.formVariables.lastName#">
                        , <cfqueryparam cfsqltype="CF_SQL_VARCHAR" value="#arguments.formVariables.phone#">)
                </cfquery>

                <cftransaction action="commit" />

                    <cfquery name="getID" datasource="#request.dsn#">
                        select max artistid
                        from GSTARTED.ARTISTS
                    </cfquery>

                    <cfquery name="updateInsert" datasource="#request.dsn#">
                        update artists
                        set city = "Boston"
                        where artistID = #getid.artistid#
                    </cfquery>
            </cftransaction>


            <cfcatch type="Database"><cfset isSuccessful=false></cfcatch>
        </cftry>
        <cfreturn isSuccessful>
    </cffunction>


    <cffunction access="public" name="updateArtist" output="false" returntype="boolean">
        <cfargument name="formVariables" type="struct" required="yes">
        <cfset isSuccessful=true>
        <cftry>
            <cfquery name="artistUpdate" datasource="#request.dsn#">
                UPDATE ARTISTS
                SET FIRSTNAME = <cfqueryparam cfsqltype="CF_SQL_VARCHAR" value="#arguments.formVariables.firstName#">,
                LASTNAME = <cfqueryparam cfsqltype="CF_SQL_VARCHAR" value="#arguments.formVariables.lastName#">,
                PHONE = <cfqueryparam cfsqltype="CF_SQL_VARCHAR" value="#arguments.formVariables.phone#">
                WHERE ARTISTID = <cfqueryparam cfsqltype="CF_SQL_VARCHAR" value="#arguments.formVariables.artistID#">
            </cfquery>
            <cfcatch type="Database"><cfset isSuccessful=false></cfcatch>
        </cftry>
        <cfreturn isSuccessful>
    </cffunction>


    <cffunction access="public" name="deleteArtist" output="false" returntype="boolean">
        <cfargument name="artistID" type="numeric" required="yes">
        <cfset isSuccessful=true>
        <cftry>
            <cfquery name="artistDelete" datasource="#request.dsn#">
                DELETE FROM GSTARTED.ARTISTS
                WHERE ARTISTID = <cfqueryparam cfsqltype="CF_SQL_VARCHAR" value="#arguments.artistID#">
            </cfquery>
            <cfcatch type="Database"><cfset isSuccessful=false></cfcatch>
        </cftry>
        <cfreturn isSuccessful>
    </cffunction>

</cfcomponent>

--->

 
<!---
--------------------------------------------------------------------------------
 
The Artists.cfc contains two methods. The getArtists method returns all of the artists from the ARTISTS table in the database. The insertArtist method adds the submitted form variables to the database. 

The insertArtist method is used in this example.

The cfargument tag requires that a structure of form variables is passed into the method call The structure is renamed to formVariables and is used in the cfquery tag to refer to the individual fields. 

The artistsInsert query references the cfartgallery datasource registered with the ColdFusion MX 7 server. 

The SQL INSERT statement declares what fields, or columns, and table into which the data will be inserted. The VALUES statement references the form data passed in from the form. 

The cfreturn tag passes a status statement back to the calling page.
---> 
